Ridin' with the King

#### Iconic Style Since 1946

The History of Lansky Bros.

#### Clothier to the King ™

Shop the Style of Elvis

## Refine Results

### Narrow by Category

Clothier To The King (35)
Shoes (16)
Activewear (5)
Coats & Jackets (25)
Sport Shirts (96)
Sweaters (6)
Neckwear (1)
T-Shirts (14)

### Narrow by Manufacturer

Clothier to the King (88)
Robert Graham (41)
Nat Nast (11)
Bed Stu (7)

See All »

### Clothier to the King

- Yes (1)

### Narrow by Keyword

## Categories

# Ridin' with the King

Other products by Clothier to the King

# Ridin' with the King

Other products by Clothier to the King
Our Price: $145.00

## About This Product

Lansky Bros. Clothier to the King proudly presents the "Ridin' With The King" custom embroidered shirt. Beautifully embroidered Pink Cadillac on the back. Pink Pick-Stiching. The front features one pocket with a suprise for the wearer... Elvis sunglasses embroidered on the inside of the pocket. Made exclusively for Lansky Bros. by Tori Richard.
70% Silk 30% Cotton.

#### Size:

+

-
Share:

## Description

Lansky Bros. Clothier to the King proudly presents the "Ridin' With The King" custom embroidered shirt. Beautifully embroidered Pink Cadillac on the back. Pink Pick-Stiching. The front features one pocket with a suprise for the wearer... Elvis sunglasses embroidered on the inside of the pocket. Made exclusively for Lansky Bros. by Tori Richard.
70% Silk 30% Cotton.

## Other Items In This Category

Lansky Rocks!
Price: $145.00
More Info
Lansky Memphis Guitar Tee - Washed Grey
Price: $20.00
More Info
Walkin' in Memphis
Price: $145.00
More Info